# vim: syntax=gnuplot
# gnuplot

set terminal postscript portrait enhanced color dashed lw 1 "Helvetica"
SCALE = 1.00
set out './Ag2m_Ag2_map_of_rovibrational_energy_levels_gnuplot_figure.eps'
set size SCALE*1.0,SCALE*0.63

set lmargin 8.5
set rmargin 6.4
## multiplot ↓
set multiplot layout 2,1
set tmargin 0.8
set bmargin 0
SplitE=-200
FigSplit=0.5
set size   1 , ((1.0-FigSplit)* (SCALE*0.63))
set origin 0 , ( FigSplit     * (SCALE*0.63))
set format x ''
unset xlabel
## multiplot ↑

set key bottom Right right
set key samplen 0.05
set key spacing 1.0

set style line 1  lt 1  lc rgb "#ac2217" lw 2
set style line 2  lt 1  lc rgb "#006221" lw 2 
set style line 3  lt 1  lc rgb "#033e8e" lw 2 
set style line 4  lt 1  lc rgb "#0ba9d8" lw 2 
set style line 5  lt 1  lc rgb "#bb4174" lw 2 
set style line 6  lt 1  lc rgb "#ddda53" lw 2 
set style line 7  lt 1  lc rgb "#343b11" lw 2 
set style line 8  lt 1  lc rgb "#2464a1" lw 2 
set style line 9  lt 1  lc rgb "#7b0815" lw 2 
set style line 10 lt 2  lc rgb "#000000" lw 0.7 dashtype 2
set style line 11 lt 1  lc rgb "#000000" lw 2
set style line 12 lt 1  lc rgb "#ffffff" lw 2

DATA = "./Ag2m_Ag2_map_of_rovibrational_energy_levels_for_gnuplot_script.dat"
MaxJ = 535
########################################################################
## Constants
_1_Bohr_in_Angstrom = 0.529177210903   # https://physics.nist.gov/cgi-bin/cuu/Value?bohrrada0  0.529177249 or 0.529177210903 or 0.52917721067 grep -E "0\.5291772" --color . -r --include='*py'
_1_Hartree_in_cmInv = 219474.63136320  # https://physics.nist.gov/cgi-bin/cuu/Convert?exp=0&num=1&From=hr&To=minv&Action=Only+show+factor   219474.63136320
_1_Hartree_in_eV    = 27.211386245988  # https://physics.nist.gov/cgi-bin/cuu/Value?hrev   27.211386245988
_1_cmInv_in_eV      = _1_Hartree_in_eV / _1_Hartree_in_cmInv
########################################################################

########################################################################
## Figure formatting

#set ylabel '{/Symbol n}' offset 1.8,0
set ylabel 'E [cm^{-1}]' offset -0.2,0

set xr[-5:MaxJ+6]
set yr[SplitE:600]
set ytics nomirror auto
set ytics 200
set mytics 4
set link y2 via (_1_cmInv_in_eV * y) inverse (y/_1_cmInv_in_eV)
set y2tics 0.02
set my2tics 4
set y2tics format '%.2f' offset -0.6

set xtics 50
set mxtics 5

set y2label  'E [eV]' offset -3.4

JtoColumnNumber_Flag(J) = (J+1)*3   # 0 → column(3) ; 1 → column(6) ; 2 → column(9)  ; 3 → column(12)
JtoColumnNumber_Enrg(J) = (J+1)*3+1 # 0 → column(4) ; 1 → column(7) ; 2 → column(10) ; 3 → column(13)

barrierJ_anion = NaN # store here the barrier value for current J
topVibAg2      = 0   # store here 1 when highest vibrational level in Ag2 neutral was encountered.
# returns vibLevel if Energy is below barrier (given in 4th row of the file: vibLevel==-4), otherwise returns NaN.
JbelowBarrierAg2minus(J,Energy,vibLevel,flag) = (( vibLevel >= 0 ) ?                         \
                                     ( \
				     (flag == 0.0) ? ((topVibAg2=1),(NaN)) : \
				         ( \
					 ((Energy <= barrierJ_anion) && (topVibAg2==1)) ? (Energy) :(NaN) \
					 ) \
				     ) \
				   : ((vibLevel==-4)?((barrierJ_anion = Energy),(topVibAg2=0),NaN):(NaN)) \
				   )

JbelowZeroAboveAg2neutral(J,Energy,vibLevel,flag) = (( vibLevel >= 0 ) ?                         \
                                     ( \
				     (flag == 0.0) ? ((topVibAg2=1),(NaN)) : \
				         ( \
					 ((Energy <= 0.0) && (topVibAg2==1)) ? (Energy) :(NaN) \
					 ) \
				     ) \
				   : ((vibLevel==-4)?((barrierJ_anion = Energy),(topVibAg2=0),NaN):(NaN)) \
				   )

JbelowBarBelowZero   (J,Energy,vibLevel,flag) = (( vibLevel >= 0 ) ?                         \
                                     ( \
				     (flag == 0.0) ? ((topVibAg2=1),(NaN)) : \
				         ( \
					 ((Energy <= barrierJ_anion) && (Energy<=0)) ? (Energy) :(NaN) \
					 ) \
				     ) \
				   : ((vibLevel==-4)?((barrierJ_anion = Energy),(topVibAg2=0),NaN):(NaN)) \
				   )
JbelowBarBelowZeroBelowAg2neutral(J,Energy,vibLevel,flag) = (( vibLevel >= 0 ) ?                         \
                                     ( \
				     (flag == 0.0) ? ((topVibAg2=1),(NaN)) : \
				         ( \
					 ((Energy <= barrierJ_anion) && (topVibAg2==0) && (Energy<=0)) ? (Energy) :(NaN) \
					 ) \
				     ) \
				   : ((vibLevel==-4)?((barrierJ_anion = Energy),(topVibAg2=0),NaN):(NaN)) \
				   )
JbelowBarAbov0_Ag2neu(J,Energy,vibLevel,flag) = (( vibLevel >= 0 ) ?                         \
                                     ( \
				     (flag == 0.0) ? ((topVibAg2=1),(NaN)) : \
				         ( \
					 ((Energy <= barrierJ_anion) && (topVibAg2==0) && Energy >= 0) ? (Energy) :(NaN) \
					 ) \
				     ) \
				   : ((vibLevel==-4)?((barrierJ_anion = Energy),(topVibAg2=0),NaN):(NaN)) \
				   )
JbelowBarrierAboveZeroAboveAg2neutral(J,Energy,vibLevel,flag) = (( vibLevel >= 0 ) ?                         \
                                     ( \
				     (flag == 0.0) ? ((topVibAg2=1),(NaN)) : \
				         ( \
					 ((Energy <= barrierJ_anion) && (topVibAg2==1) && (Energy>=0)) ? (Energy) :(NaN) \
					 ) \
				     ) \
				   : ((vibLevel==-4)?((barrierJ_anion = Energy),(topVibAg2=0),NaN):(NaN)) \
				   )
JbelowBarrierAboveZero   (J,Energy,vibLevel,flag) = (( vibLevel >= 0 ) ?                         \
                                     ( \
				     (flag == 0.0) ? ((topVibAg2=1),(NaN)) : \
				         ( \
					 ((Energy <= barrierJ_anion) && (Energy>=0)) ? (Energy) :(NaN) \
					 ) \
				     ) \
				   : ((vibLevel==-4)?((barrierJ_anion = Energy),(topVibAg2=0),NaN):(NaN)) \
				   )
# barrierJ_neutral = NaN # in fact only anyon barrier is useful.
JAg2neutral(J,Energy,vibLevel,flag) = \
				   (                                                                     \
				     ((vibLevel >= 0) && (flag==0.0))                                    \
				     ?                                                                   \
                                        ((Energy))                                                     \
				     :                                                                   \
				     (                                                                   \
					(NaN)                                                            \
				     ) \
				   )

# plot step. Plot only every S-th column (skip plenty of J). Full plot with S=1 takes about 5 minutes, be careful.
S=1

H=_1_Hartree_in_cmInv

set obj   10 rect at 70,-93 size char 2.2, char 1.2
set obj   10 fillstyle solid noborder front
set label 2 "(b)" at 70 ,-90  front center
set label 3 "(c)" at 450, 200  front center
set label 4 "(d)" at 200, 70  front center

set grid

plot \
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JbelowBarBelowZeroBelowAg2neutral    (jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#bbbbbb" notitle "a)",\
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JbelowZeroAboveAg2neutral            (jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#44cc44" notitle "b)",\
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JbelowBarAbov0_Ag2neu                (jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#6666ff" notitle "c)",\
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JbelowBarrierAboveZeroAboveAg2neutral(jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#ee4444" notitle "d)",\
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JAg2neutral                          (jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#000000" notitle "e)"

print barrierJ_anion

## multiplot ↓
set tmargin 0
set bmargin 3.1
set size   1 , (FigSplit* (SCALE*0.63))
set origin 0 , (0.0* (SCALE*0.63))
set format x
set xlabel 'J' offset 0,0.1
set yr[-11500:SplitE]
set ytics 2000
set mytics 4
set y2tics 0.2
set my2tics 4
set y2tics format '%.2f' offset -0.6
set ylabel 'E [cm^{-1}]' offset 1.8,0
## multiplot ↑

#unset label 1
unset label 2
unset label 3
unset label 4
unset obj 10
set label 1 "(a)" at 160,-6000 front
set label 5 "(e)" at 160,-3300 front center
set arrow 6 from 145,-3200 to 105,-2600 head filled lw 0.2 lt rgb "#000000" front

plot \
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JbelowBarBelowZeroBelowAg2neutral    (jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#bbbbbb" notitle "a)",\
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JbelowZeroAboveAg2neutral            (jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#44cc44" notitle "b)",\
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JbelowBarAbov0_Ag2neu                (jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#6666ff" notitle "c)",\
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JbelowBarrierAboveZeroAboveAg2neutral(jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#ee4444" notitle "d)",\
for [jjj=0:(MaxJ)/S] DATA u (jjj*S):(H*JAg2neutral                          (jjj*S,(column(JtoColumnNumber_Enrg(jjj*S))),(column(1)),(column(JtoColumnNumber_Flag(jjj*S))))) w points pointtype 5 pointsize 0.10 lt rgb "#000000" notitle "e)",\
NaN w points pointtype 5 pointsize 1.10 lt rgb "#bbbbbb" title "(a)",\
NaN w points pointtype 5 pointsize 1.10 lt rgb "#44cc44" title "(b)",\
NaN w points pointtype 5 pointsize 1.10 lt rgb "#6666ff" title "(c)",\
NaN w points pointtype 5 pointsize 1.10 lt rgb "#ee4444" title "(d)",\
NaN w points pointtype 5 pointsize 1.10 lt rgb "#000000" title "(e)"


unset multiplot

